%global _ld_strict_symbol_defs 1

Summary:        Extended crypt library for descrypt, md5crypt, bcrypt, and others
Name:           libxcrypt
Version:        4.4.36
Release:        4%{?dist}
License:        LGPLv2+ and BSD and Public Domain
URL:            https://github.com/besser82/%{name}
Source0:        https://github.com/besser82/libxcrypt/archive/v%{version}.tar.gz

Patch5000:      add-sm3-support.patch
Patch5001:	add-loongarch-support-for-libxcrypt.patch

BuildRequires:  gcc, make, autoconf, libtool
BuildRequires:  glibc-devel >= 2.28, perl-core
Recommends:     mkpasswd

Provides: %{name}-static, %{name}-compat

%description
libxcrypt is a modern library for one-way hashing of passwords.  It
supports a wide variety of both modern and historical hashing methods:
yescrypt, gost-yescrypt, scrypt, bcrypt, sha512crypt, sha256crypt,
md5crypt, SunMD5, sha1crypt, NT, bsdicrypt, bigcrypt, and descrypt.
It provides the traditional Unix crypt and crypt_r interfaces, as well
as a set of extended interfaces pioneered by Openwall Linux, crypt_rn,
crypt_ra, crypt_gensalt, crypt_gensalt_rn, and crypt_gensalt_ra.

libxcrypt is intended to be used by login(1), passwd(1), and other
similar programs; that is, to hash a small number of passwords during
an interactive authentication dialogue with a human. It is not suitable
for use in bulk password-cracking applications, or in any other situation
where speed is more important than careful handling of sensitive data.
However, it is intended to be fast and lightweight enough for use in
servers that must field thousands of login attempts per minute.
This version of the library does not provide the legacy API functions
that have been provided by glibc's libcrypt.so.1.


%package        devel
Summary:        Development files for %{name}
Requires:       %{name}        = %{version}-%{release}
Requires:       glibc-devel   >= 2.28

%description    devel
This package provides header files and libraries for developers
who use libxcrypt.

%prep
%autosetup -p1

%build
autoreconf -fiv
%global _configure "$(realpath ../configure)"

mkdir -p %{_vpath_builddir}

pushd %{_vpath_builddir}
%configure                                       \
  --disable-failure-tokens                       \
  --disable-silent-rules                         \
  --enable-shared                                \
  --enable-static                                \
  --disable-valgrind                             \
  --srcdir=$(realpath ..)                        \
  --with-pkgconfigdir=%{_libdir}/pkgconfig       \
  --enable-hashes=all                            \
  --enable-obsolete-api=glibc
%make_build
%make_build test-programs
popd

%install
%make_install -C %{_vpath_builddir}

find %{buildroot} -name '*.la' -delete -print

%check
for dir in "%{_vpath_builddir}"; do
  %make_build -C ${dir} check || \
    {
      rc=$?;
      cat ${dir}/test-suite.log;
      exit $rc;
    }
done


%files
%license AUTHORS COPYING.LIB LICENSING
%doc NEWS README THANKS
%{_libdir}/libcrypt.so
%{_libdir}/libcrypt.so.*
%{_libdir}/libxcrypt.so
%{_mandir}/man5/crypt.5*
%{_mandir}/man3/crypt.3*


%files devel
%doc ChangeLog TODO
%{_includedir}/crypt.h
%{_includedir}/xcrypt.h
%{_libdir}/pkgconfig/libcrypt.pc
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/libxcrypt.a
%{_libdir}/libcrypt.a
%{_mandir}/man3/crypt_r.3*
%{_mandir}/man3/crypt_ra.3*
%{_mandir}/man3/crypt_rn.3*
%{_mandir}/man3/crypt_checksalt.3*
%{_mandir}/man3/crypt_gensalt.3*
%{_mandir}/man3/crypt_gensalt_ra.3*
%{_mandir}/man3/crypt_gensalt_rn.3*
%{_mandir}/man3/crypt_preferred_method.3*

%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.4.36-4
- Rebuilt for loongarch release

* Wed Mar  6 2024 Wenlong Zhang <zhangwenlong@loongson.cn> - 4.4.36-3
- Fix build error for loongarch64

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.4.36-2
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Aug 01 2023 Miaojun Dong <zoedong@tencent.com> - 4.4.36-1
- Bump version to 4.4.36

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.4.28-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.4.28-3
- Rebuilt for OpenCloudOS Stream 23

* Mon Mar 06 2023 Miaojun Dong <zoedong@tencent.com> - 4.4.28-2
- add sm3 support

* Mon Jun 13 2022 cunshunxia <cunshunxia@tencent.com> - 4.4.28-1
- initial build
